# Table of Contents

- [exporting-fact-sheet-data-as-excel-file](<./exporting-fact-sheet-data-as-excel-file.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Exporting Fact Sheet Data as Excel File](<./Exporting-Fact-Sheet-Data-as-Excel-File.md>)
  - [Introduction](<./Exporting-Fact-Sheet-Data-as-Excel-File/Introduction.md>)
  - [Exporting Fact Sheet Data as an Excel File](<./Exporting-Fact-Sheet-Data-as-Excel-File/Exporting-Fact-Sheet-Data-as-an-Excel-File.md>)
  - [Creating a Template for Import](<./Exporting-Fact-Sheet-Data-as-Excel-File/Creating-a-Template-for-Import.md>)
